#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_content.shared.site import IWfSiteTopic
from pyams_content.shared.site.interfaces import ISiteFolder, ISiteManager, ISiteContainer
from pyams_i18n.interfaces import II18n
from pyams_sequence.interfaces import ISequentialIdInfo
from pyams_skin.interfaces.metas import IHTMLContentMetas
from pyams_skin.layer import IPyAMSUserLayer
from pyams_skin.metas import ContentMeta, HTMLTagMeta
from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config, ContextRequestAdapter
from pyams_utils.interfaces.url import ICanonicalURL
from pyams_utils.traversing import get_parent
from pyams_utils.url import absolute_url


@adapter_config(name='title', context=(ISiteManager, IPyAMSUserLayer, Interface), provides=IHTMLContentMetas)
@adapter_config(name='title', context=(ISiteFolder, IPyAMSUserLayer, Interface), provides=IHTMLContentMetas)
class SiteContainerTitleMetasAdapter(ContextRequestViewAdapter):
    """Site container metas adapter"""

    order = 1

    def get_metas(self):
        i18n = II18n(self.context)
        title = i18n.query_attribute('title', request=self.request)
        yield HTMLTagMeta('title', title)
        description = i18n.query_attribute('description', request=self.request)
        if (not description) and hasattr(self.context, 'header'):
            description = i18n.query_attribute('header', request=self.request)
        if description:
            yield ContentMeta('description', description)


@adapter_config(context=(IWfSiteTopic, IPyAMSUserLayer), provides=ICanonicalURL)
class SiteTopicCanonicalUrlAdapter(ContextRequestAdapter):
    """Site topic canonical URL adapter"""

    def get_url(self, view_name=None, query=None):
        parent = get_parent(self.context, ISiteContainer)
        return absolute_url(parent, self.request,
                            '++oid++{0}::{1}{2}{3}'.format(
                                ISequentialIdInfo(self.context).get_base_oid().strip(),
                                self.context.content_url,
                                '/{}'.format(view_name) if view_name else '.html',
                                '?{}'.format(query) if query else ''))
